import { useRoute, createRouter, RouteRecordRaw, createWebHashHistory } from 'vue-router';
import Layout from '@/layouts/index.vue';
import { getUserStore } from '@/store';
// 其他固定路由
const allRoutes: Array<RouteRecordRaw> = [
    {
        path: '/login',
        name: 'login',
        component: () => import('@/views/login/index.vue'),
    },
    {
        path: '/',
        redirect: '/runData',
    },
    {
        path: '/runData',
        component: Layout,
        redirect: '/runData/index',
        name: 'runData',
        children: [
            {
                path: 'index',
                name: 'runDataIndex',
                component: () => import('@/views/runData/index.vue'),
                meta: { title: '运行数据' },
            }]
    },
    {
        path: '/logsData',
        component: Layout,
        redirect: '/logsData/index',
        name: 'logsData',
        children: [
            {
                path: 'index',
                name: 'logsDataIndex',
                component: () => import('@/views/logs/index.vue'),
                meta: { title: '日志数据' },
            }]
    }

    // {
    //     path: '/demo',
    //     component: Layout,
    //     redirect: '/demo/index',
    //     name: 'demo',
    //     children: [
    //         {
    //             path: 'index',
    //             name: 'demoIndex',
    //             component: () => import('@/views/demo/index.vue'),
    //             meta: { title: 'demo数据' },
    //         }]
    // }
];



export const getActive = (maxLevel = 3): string => {
    const route = useRoute();
    if (!route.path) {
        return '';
    }

    return route.path
        .split('/')
        .filter((_item: string, index: number) => index <= maxLevel && index > 0)
        .map((item: string) => `/${item}`)
        .join('');
};

const router = createRouter({
    history: createWebHashHistory(),
    //   history: createWebHistory(import.meta.env.BASE_URL),
    routes: allRoutes,
    scrollBehavior() {
        return {
            el: '#app',
            top: 0,
            behavior: 'smooth',
        };
    },
});



export default router;

router.beforeEach(async (to, from, next) => {
    const whiteListRouters = ['/login'];
    const userStore = getUserStore();
    const { userInfo } = userStore;
    if (userInfo.username) {
        if (to.path === '/login') {
            next();
            return;
        }
        next();

    } else {
        /* white list router */
        if (whiteListRouters.indexOf(to.path) !== -1) {
            next();
        } else {
            next({
                path: '/login'
            });
        }

    }
});

router.afterEach(() => {

});


